@@ -1,10 +1,8 @@
 ## @file
 # Base package for all Lemonldap::NG CGI
-#
-# @copy 2005, 2006, 2007, 2008, Xavier Guimard &lt;x.guimard@free.fr&gt;
 
 ## @class
-# Base class for all Lemonldap::NG portal CGI
+# Base class for all Lemonldap::NG CGI
 package Lemonldap::NG::Common::CGI;
 
 use strict;
@@ -13,28 +11,39 @@ use MIME::Base64;
 use Time::Local;
 use CGI;
 
-our $VERSION = '0.31';
+our $VERSION = '0.4';
 
 use base qw(CGI);
 
+## @method void soapTest(string soapFunctions object obj)
+# Check if request is a SOAP request. If it is, launch
+# Lemonldap::NG::Common::CGI::SOAPServer and exit. Else simply return.
+# @param $soapFunctions list of authorized functions.
+# @param $obj optional object that will receive SOAP requests
 sub soapTest {
-    my $self = shift;
-    my $soapFunctions = shift || $self->{SOAPFunctions};
+    my($self, $soapFunctions, $obj) = @_;
 
     # If non form encoded datas are posted, we call SOAP Services
     if ( $ENV{HTTP_SOAPACTION} ) {
-        my @func = ();
-        foreach ( ref($soapFunctions) ? @$soapFunctions : split /\s+/, $soapFunctions ) {
-            $_ = ref($self) . "::$_" unless (/::/);
-            push @func, $_;
-        }
-        Lemonldap::NG::Common::CGI::SOAPServer->dispatch_to(@func)
+        require Lemonldap::NG::Common::CGI::SOAPServer; #link protected dispatcher
+        require Lemonldap::NG::Common::CGI::SOAPService; #link protected soapService
+        my @func = ( ref($soapFunctions) ? @$soapFunctions : split /\s+/, $soapFunctions );
+        my $dispatcher = Lemonldap::NG::Common::CGI::SOAPService->new($obj||$self,@func);
+        Lemonldap::NG::Common::CGI::SOAPServer->dispatch_to($dispatcher)
           ->handle($self);
         exit;
     }
-    return $self;
 }
 
+## @method string header_public(string filename)
+# Implements the "304 Not Modified" HTTP mechanism.
+# If HTTP request contains an "If-Modified-Since" header and if
+# $filename was not modified since, prints the "304 Not Modified" response and
+# exit. Else, launch CGI::header() with "Cache-Control" and "Last-Modified"
+# headers.
+# @param $filename Optional name of the reference file. Default
+# $ENV{SCRIPT_FILENAME}.
+# @return Common Gateway Interface standard response header
 sub header_public {
     my $self     = shift;
     my $filename = shift;
@@ -79,6 +88,11 @@ sub header_public {
     );
 }
 
+## @method void abort(string title, string text)
+# Display an error message and exit.
+# Used instead of die() in Lemonldap::NG CGIs.
+# @param title Title of the error message
+# @param text Optional text. Default: "See Apache's logs"
 sub abort {
     my $self = shift;
     my $cgi  = CGI->new;
@@ -97,69 +111,6 @@ sub abort {
     exit;
 }
 
-package Lemonldap::NG::Common::CGI::SOAPServer;
-use SOAP::Transport::HTTP;
-use base 'SOAP::Transport::HTTP::Server';
-
-sub DESTROY { SOAP::Trace::objects('()') }
-
-sub new {
-    my $self = shift;
-    return $self if ref $self;
-
-    my $class = ref($self) || $self;
-    $self = $class->SUPER::new(@_);
-    SOAP::Trace::objects('()');
-
-    return $self;
-}
-
-sub handle {
-    my $self = shift->new;
-    my $cgi  = shift;
-
-    my $content = $cgi->param('POSTDATA');
-    my $length  = length($content);
-
-    if ( !$length ) {
-        $self->response( HTTP::Response->new(411) )    # LENGTH REQUIRED
-    }
-    elsif ( defined $SOAP::Constants::MAX_CONTENT_SIZE
-        && $length > $SOAP::Constants::MAX_CONTENT_SIZE )
-    {
-        $self->response( HTTP::Response->new(413) )   # REQUEST ENTITY TOO LARGE
-    }
-    else {
-        $self->request(
-            HTTP::Request->new(
-                'POST' => $ENV{'SCRIPT_NAME'},
-                HTTP::Headers->new(
-                    map {
-                        (
-                              /^HTTP_(.+)/i
-                            ? ( $1 =~ m/SOAPACTION/ )
-                                  ? ('SOAPAction')
-                                  : ($1)
-                            : $_
-                          ) => $ENV{$_}
-                      } keys %ENV
-                ),
-                $content,
-            )
-        );
-        $self->SUPER::handle;
-    }
-
-    print $cgi->header(
-        -status => $self->response->code . " "
-          . HTTP::Status::status_message( $self->response->code ),
-        -type           => $self->response->header('Content-Type'),
-        -Content_Length => $self->response->header('Content-Length'),
-        -SOAPServer     => 'Lemonldap::NG CGI',
-    );
-    print $self->response->content;
-}
-
 1;
 
 __END__
