@@ -1,21 +1,18 @@
 package Lemonldap::NG::Common::Conf::File;
 
 use strict;
-use Lemonldap::NG::Common::Conf::Constants;    #inherits
-use Lemonldap::NG::Common::Conf::Serializer;
+use Lemonldap::NG::Common::Conf::Constants;
 
-our $VERSION = '0.99.1';
+our $VERSION = 0.22;
 
 sub prereq {
     my $self = shift;
     unless ( $self->{dirName} ) {
-        $Lemonldap::NG::Common::Conf::msg =
-          '"dirName" is required in "File" configuration type !';
+        $Lemonldap::NG::Common::Conf::msg = '"dirName" is required in "File" configuration type !';
         return 0;
     }
     unless ( -d $self->{dirName} ) {
-        $Lemonldap::NG::Common::Conf::msg =
-          "Directory \"$self->{dirName}\" does not exist !";
+        $Lemonldap::NG::Common::Conf::msg = "Directory \"$self->{dirName}\" does not exist !";
         return 0;
     }
     1;
@@ -38,13 +35,12 @@ sub lastCfg {
 
 sub lock {
     my $self = shift;
-    if ( $self->isLocked ) {
+    if( $self->isLocked ) {
         sleep 2;
-        return 0 if ( $self->isLocked );
+        return 0 if( $self->isLocked );
     }
-    unless ( open F, ">" . $self->{dirName} . "/lmConf.lock" ) {
-        $Lemonldap::NG::Common::Conf::msg =
-          "Unable to lock (" . $self->{dirName} . "/lmConf.lock)\n";
+    unless( open F, ">".$self->{dirName} . "/lmConf.lock" ) {
+        $Lemonldap::NG::Common::Conf::msg = "Unable to lock (".$self->{dirName}."/lmConf.lock)\n";
         return 0;
     }
     print F $$;
@@ -64,21 +60,18 @@ sub unlock {
 
 sub store {
     my ( $self, $fields ) = @_;
-    $fields = $self->serialize($fields);
     my $mask = umask;
-    umask( oct('0027') );
-    unless ( open FILE,
-        '>' . $self->{dirName} . "/lmConf-" . $fields->{cfgNum} )
-    {
+    umask ( oct ( '0027' ) );
+    unless( open FILE, '>' . $self->{dirName} . "/lmConf-" . $fields->{cfgNum} ) {
         $Lemonldap::NG::Common::Conf::msg = "Open file failed: $!";
         $self->unlock;
         return UNKNOWN_ERROR;
     }
-    foreach my $k ( sort keys %$fields ) {
-        print FILE "$k\n\t$fields->{$k}\n\n";
+    while ( my ( $k, $v ) = each(%$fields) ) {
+        print FILE "$k\n\t$v\n\n";
     }
     close FILE;
-    umask($mask);
+    umask( $mask );
     $self->unlock;
     return $fields->{cfgNum};
 }
@@ -100,13 +93,12 @@ sub load {
         }
     }
     close FILE;
-    return $self->unserialize($f);
+    return $f;
 }
 
 sub delete {
     my ( $self, $cfgNum ) = @_;
-    unlink( $self->{dirName} . "/lmConf-$cfgNum" );
+    unlink ( $self->{dirName} . "/lmConf-$cfgNum" );
 }
 
-1;
 __END__
